@@ -144,26 +144,14 @@ register_element_cls('w:tcW',       CT_TblWidth)
 register_element_cls('w:tr',        CT_Row)
 register_element_cls('w:vMerge',    CT_VMerge)
 
-from .text.paragraph import CT_Ind, CT_Jc, CT_P, CT_PPr, CT_Spacing
-register_element_cls('w:ind',             CT_Ind)
-register_element_cls('w:jc',              CT_Jc)
-register_element_cls('w:keepLines',       CT_OnOff)
-register_element_cls('w:keepNext',        CT_OnOff)
-register_element_cls('w:p',               CT_P)
-register_element_cls('w:pageBreakBefore', CT_OnOff)
-register_element_cls('w:pPr',             CT_PPr)
-register_element_cls('w:pStyle',          CT_String)
-register_element_cls('w:spacing',         CT_Spacing)
-register_element_cls('w:widowControl',    CT_OnOff)
-
-from .text.run import (
-    CT_Br, CT_Fonts, CT_HpsMeasure, CT_R, CT_RPr, CT_Text, CT_Underline,
+from .text.font import (
+    CT_Color, CT_Fonts, CT_HpsMeasure, CT_RPr, CT_Underline,
     CT_VerticalAlignRun
 )
 register_element_cls('w:b',          CT_OnOff)
 register_element_cls('w:bCs',        CT_OnOff)
-register_element_cls('w:br',         CT_Br)
 register_element_cls('w:caps',       CT_OnOff)
+register_element_cls('w:color',      CT_Color)
 register_element_cls('w:cs',         CT_OnOff)
 register_element_cls('w:dstrike',    CT_OnOff)
 register_element_cls('w:emboss',     CT_OnOff)
@@ -173,7 +161,6 @@ register_element_cls('w:imprint',    CT_OnOff)
 register_element_cls('w:noProof',    CT_OnOff)
 register_element_cls('w:oMath',      CT_OnOff)
 register_element_cls('w:outline',    CT_OnOff)
-register_element_cls('w:r',          CT_R)
 register_element_cls('w:rFonts',     CT_Fonts)
 register_element_cls('w:rPr',        CT_RPr)
 register_element_cls('w:rStyle',     CT_String)
@@ -184,8 +171,26 @@ register_element_cls('w:snapToGrid', CT_OnOff)
 register_element_cls('w:specVanish', CT_OnOff)
 register_element_cls('w:strike',     CT_OnOff)
 register_element_cls('w:sz',         CT_HpsMeasure)
-register_element_cls('w:t',          CT_Text)
 register_element_cls('w:u',          CT_Underline)
 register_element_cls('w:vanish',     CT_OnOff)
 register_element_cls('w:vertAlign',  CT_VerticalAlignRun)
 register_element_cls('w:webHidden',  CT_OnOff)
+
+from .text.paragraph import CT_P
+register_element_cls('w:p', CT_P)
+
+from .text.parfmt import CT_Ind, CT_Jc, CT_PPr, CT_Spacing
+register_element_cls('w:ind',             CT_Ind)
+register_element_cls('w:jc',              CT_Jc)
+register_element_cls('w:keepLines',       CT_OnOff)
+register_element_cls('w:keepNext',        CT_OnOff)
+register_element_cls('w:pageBreakBefore', CT_OnOff)
+register_element_cls('w:pPr',             CT_PPr)
+register_element_cls('w:pStyle',          CT_String)
+register_element_cls('w:spacing',         CT_Spacing)
+register_element_cls('w:widowControl',    CT_OnOff)
+
+from .text.run import CT_Br, CT_R, CT_Text
+register_element_cls('w:br', CT_Br)
+register_element_cls('w:r',  CT_R)
+register_element_cls('w:t',  CT_Text)
