@@ -9,12 +9,56 @@ from __future__ import absolute_import, print_function, unicode_literals
 import pytest
 
 from docx.enum.section import WD_ORIENT, WD_SECTION
-from docx.section import Section
+from docx.section import Section, Sections
 from docx.shared import Inches
 
 from .unitutil.cxml import element, xml
 
 
+class DescribeSections(object):
+
+    def it_knows_how_many_sections_it_contains(self, len_fixture):
+        sections, expected_len = len_fixture
+        assert len(sections) == expected_len
+
+    def it_can_iterate_over_its_Section_instances(self, iter_fixture):
+        sections, expected_count = iter_fixture
+        section_count = 0
+        for section in sections:
+            section_count += 1
+            assert isinstance(section, Section)
+        assert section_count == expected_count
+
+    def it_can_access_its_Section_instances_by_index(self, index_fixture):
+        sections, indicies = index_fixture
+        assert len(sections[0:2]) == 2
+        for index in indicies:
+            assert isinstance(sections[index], Section)
+
+    # fixtures -------------------------------------------------------
+
+    @pytest.fixture
+    def index_fixture(self, document_elm):
+        sections = Sections(document_elm)
+        return sections, [0, 1]
+
+    @pytest.fixture
+    def iter_fixture(self, document_elm):
+        sections = Sections(document_elm)
+        return sections, 2
+
+    @pytest.fixture
+    def len_fixture(self, document_elm):
+        sections = Sections(document_elm)
+        return sections, 2
+
+    # fixture components ---------------------------------------------
+
+    @pytest.fixture
+    def document_elm(self):
+        return element('w:document/w:body/(w:p/w:pPr/w:sectPr, w:sectPr)')
+
+
 class DescribeSection(object):
 
     def it_knows_its_start_type(self, start_type_get_fixture):
